Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Store ¶
type Store struct {
// RootDir defines the root file path of the cache
RootDir string
// MaxAge is the implementation of cache.MaxAge for use during trimming old files
MaxAge cache.MaxAge
// contains filtered or unexported fields
}
Store implements cache.Store
func New ¶
New initializes a new instance of the disk store to be added to the current cache. If MaxAge or RootDir are not provided the will be set to their default values.
func (*Store) Purge ¶
Purge will clear the entire cache and remove the RootDir. This function should only be used when stopping the service. If you need to flush the store without stopping it you can call this method directly.
Click to show internal directories.
Click to hide internal directories.