Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Store ¶
type Store struct {
// MaxAge is the implementation of cache.MaxAge for use during trimming old key-value pairs
MaxAge cache.MaxAge
// contains filtered or unexported fields
}
Store implements cache.Store
func New ¶
New will initialize a new in-memory store This is not persistent through reboots and should be used for short lived tasks.
func (*Store) Purge ¶
Purge clears the entire in-memory store. This function should only be used when stopping the service. If you need to flush the store without stopping it you can call this method directly. This will never return an error.
Click to show internal directories.
Click to hide internal directories.